@@ -63,16 +63,10 @@ class Alarms:
             )
         '''
         if __debug__:
-            def stub(
-                *,
-                lower_alarm_interval_index: typing.Optional[jsii.Number] = None,
-                upper_alarm_interval_index: typing.Optional[jsii.Number] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__2ee477f5403e203a69501fa2e647ddaf59c853a14878147d021d4cf742e12d16)
             check_type(argname="argument lower_alarm_interval_index", value=lower_alarm_interval_index, expected_type=type_hints["lower_alarm_interval_index"])
             check_type(argname="argument upper_alarm_interval_index", value=upper_alarm_interval_index, expected_type=type_hints["upper_alarm_interval_index"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if lower_alarm_interval_index is not None:
             self._values["lower_alarm_interval_index"] = lower_alarm_interval_index
         if upper_alarm_interval_index is not None:
@@ -110,7 +104,7 @@ class ArbitraryIntervals:
         self,
         *,
         absolute: builtins.bool,
-        intervals: typing.Sequence[typing.Union["ScalingInterval", typing.Dict[str, typing.Any]]],
+        intervals: typing.Sequence[typing.Union["ScalingInterval", typing.Dict[builtins.str, typing.Any]]],
     ) -> None:
         '''
         :param absolute: 
@@ -136,16 +130,10 @@ class ArbitraryIntervals:
             )
         '''
         if __debug__:
-            def stub(
-                *,
-                absolute: builtins.bool,
-                intervals: typing.Sequence[typing.Union["ScalingInterval", typing.Dict[str, typing.Any]]],
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__4f44e32e1feb963056171911edfb776d5d46953ce5fdae8544ae0247c1c57287)
             check_type(argname="argument absolute", value=absolute, expected_type=type_hints["absolute"])
             check_type(argname="argument intervals", value=intervals, expected_type=type_hints["intervals"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "absolute": absolute,
             "intervals": intervals,
         }
@@ -209,18 +197,11 @@ class CompleteScalingInterval:
             )
         '''
         if __debug__:
-            def stub(
-                *,
-                lower: jsii.Number,
-                upper: jsii.Number,
-                change: typing.Optional[jsii.Number] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__707e7bdd6c7a5151d6f09d060436d9dd47b89c17f23510f97aa515913a67460f)
             check_type(argname="argument lower", value=lower, expected_type=type_hints["lower"])
             check_type(argname="argument upper", value=upper, expected_type=type_hints["upper"])
             check_type(argname="argument change", value=change, expected_type=type_hints["change"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "lower": lower,
             "upper": upper,
         }
@@ -285,9 +266,7 @@ class _IRandomGeneratorProxy:
         :param max: -
         '''
         if __debug__:
-            def stub(min: jsii.Number, max: jsii.Number) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__69a0e3cfd932f09838c7b1efb5c430fdc2fa45328cfa3e033d6dd207f384f81a)
             check_type(argname="argument min", value=min, expected_type=type_hints["min"])
             check_type(argname="argument max", value=max, expected_type=type_hints["max"])
         return typing.cast(jsii.Number, jsii.invoke(self, "nextInt", [min, max]))
@@ -332,18 +311,11 @@ class ScalingInterval:
             )
         '''
         if __debug__:
-            def stub(
-                *,
-                change: jsii.Number,
-                lower: typing.Optional[jsii.Number] = None,
-                upper: typing.Optional[jsii.Number] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__38b7e593202926386b084b317d62d4808493cee80c8e11cbc30e099743d76837)
             check_type(argname="argument change", value=change, expected_type=type_hints["change"])
             check_type(argname="argument lower", value=lower, expected_type=type_hints["lower"])
             check_type(argname="argument upper", value=upper, expected_type=type_hints["upper"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "change": change,
         }
         if lower is not None:
@@ -411,3 +383,44 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__2ee477f5403e203a69501fa2e647ddaf59c853a14878147d021d4cf742e12d16(
+    *,
+    lower_alarm_interval_index: typing.Optional[jsii.Number] = None,
+    upper_alarm_interval_index: typing.Optional[jsii.Number] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4f44e32e1feb963056171911edfb776d5d46953ce5fdae8544ae0247c1c57287(
+    *,
+    absolute: builtins.bool,
+    intervals: typing.Sequence[typing.Union[ScalingInterval, typing.Dict[builtins.str, typing.Any]]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__707e7bdd6c7a5151d6f09d060436d9dd47b89c17f23510f97aa515913a67460f(
+    *,
+    lower: jsii.Number,
+    upper: jsii.Number,
+    change: typing.Optional[jsii.Number] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__69a0e3cfd932f09838c7b1efb5c430fdc2fa45328cfa3e033d6dd207f384f81a(
+    min: jsii.Number,
+    max: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__38b7e593202926386b084b317d62d4808493cee80c8e11cbc30e099743d76837(
+    *,
+    change: jsii.Number,
+    lower: typing.Optional[jsii.Number] = None,
+    upper: typing.Optional[jsii.Number] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
